==> qt6-webengine_6.2.4+dfsg.orig.tar.xz: qtwebengine-everywhere-src-6.2.4/src/3rdparty/chromium/chrome/browser/net/profile_network_context_service_factory.h <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_NET_PROFILE_NETWORK_CONTEXT_SERVICE_FACTORY_H_
#define CHROME_BROWSER_NET_PROFILE_NETWORK_CONTEXT_SERVICE_FACTORY_H_

#include "base/macros.h"
#include "base/memory/singleton.h"
#include "components/keyed_service/content/browser_context_keyed_service_factory.h"

class KeyedService;
class ProfileNetworkContextService;

namespace content {
class BrowserContext;
}

class ProfileNetworkContextServiceFactory
    : public BrowserContextKeyedServiceFactory {
 public:
  // Returns the ProfileNetworkContextService that supports NetworkContexts for
  // |browser_context|.
  static ProfileNetworkContextService* GetForContext(
      content::BrowserContext* browser_context);

  // Returns the NetworkContextServiceFactory singleton.
  static ProfileNetworkContextServiceFactory* GetInstance();

 private:
  friend struct base::DefaultSingletonTraits<
      ProfileNetworkContextServiceFactory>;

  ProfileNetworkContextServiceFactory();
  ~ProfileNetworkContextServiceFactory() override;

  // BrowserContextKeyedServiceFactory implementation:
  KeyedService* BuildServiceInstanceFor(
      content::BrowserContext* profile) const override;
  content::BrowserContext* GetBrowserContextToUse(
      content::BrowserContext* context) const override;
  bool ServiceIsNULLWhileTesting() const override;

  DISALLOW_COPY_AND_ASSIGN(ProfileNetworkContextServiceFactory);
};

#endif  // CHROME_BROWSER_NET_PROFILE_NETWORK_CONTEXT_SERVICE_FACTORY_H_

==> qt6-webengine_6.10.2+dfsg.orig.tar.xz: qtwebengine-everywhere-src-6.10.2/src/3rdparty/chromium/chrome/browser/net/profile_network_context_service_factory.h <==
// Copyright 2017 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_NET_PROFILE_NETWORK_CONTEXT_SERVICE_FACTORY_H_
#define CHROME_BROWSER_NET_PROFILE_NETWORK_CONTEXT_SERVICE_FACTORY_H_

#include "base/no_destructor.h"
#include "chrome/browser/profiles/profile_keyed_service_factory.h"

class KeyedService;
class ProfileNetworkContextService;

namespace content {
class BrowserContext;
}

class ProfileNetworkContextServiceFactory : public ProfileKeyedServiceFactory {
 public:
  // Returns the ProfileNetworkContextService that supports NetworkContexts for
  // |browser_context|.
  static ProfileNetworkContextService* GetForContext(
      content::BrowserContext* browser_context);

  // Returns the NetworkContextServiceFactory singleton.
  static ProfileNetworkContextServiceFactory* GetInstance();

  ProfileNetworkContextServiceFactory(
      const ProfileNetworkContextServiceFactory&) = delete;
  ProfileNetworkContextServiceFactory& operator=(
      const ProfileNetworkContextServiceFactory&) = delete;

 private:
  friend base::NoDestructor<ProfileNetworkContextServiceFactory>;

  ProfileNetworkContextServiceFactory();
  ~ProfileNetworkContextServiceFactory() override;

  // BrowserContextKeyedServiceFactory implementation:
  std::unique_ptr<KeyedService> BuildServiceInstanceForBrowserContext(
      content::BrowserContext* profile) const override;
  bool ServiceIsNULLWhileTesting() const override;
};

#endif  // CHROME_BROWSER_NET_PROFILE_NETWORK_CONTEXT_SERVICE_FACTORY_H_
